public inbox for devel@edk2.groups.io
 help / color / mirror / Atom feed
From: "Rabeda, Maciej" <maciej.rabeda@intel.com>
To: Philippe Mathieu-Daude <philmd@redhat.com>,
	"devel@edk2.groups.io" <devel@edk2.groups.io>
Cc: Antoine Coeur <coeur@gmx.fr>, "Wu, Jiaxin" <jiaxin.wu@intel.com>,
	"Fu, Siyuan" <siyuan.fu@intel.com>
Subject: Re: [PATCH 44/79] NetworkPkg/Library: Fix various typos
Date: Fri, 6 Dec 2019 16:04:25 +0000	[thread overview]
Message-ID: <SN6PR11MB35357B0AFA6595E9A8E79272F95F0@SN6PR11MB3535.namprd11.prod.outlook.com> (raw)
In-Reply-To: <20191203161602.15969-45-philmd@redhat.com>

Reviewed-by: Maciej Rabeda <maciej.rabeda@intel.com>

Thanks!
Maciej

-----Original Message-----
From: Philippe Mathieu-Daude <philmd@redhat.com> 
Sent: Tuesday, December 3, 2019 17:15
To: devel@edk2.groups.io
Cc: Antoine Coeur <coeur@gmx.fr>; Wu, Jiaxin <jiaxin.wu@intel.com>; Fu, Siyuan <siyuan.fu@intel.com>; Rabeda, Maciej <maciej.rabeda@intel.com>; Philippe Mathieu-Daude <philmd@redhat.com>
Subject: [PATCH 44/79] NetworkPkg/Library: Fix various typos

From: Antoine Coeur <coeur@gmx.fr>

Fix various typos in comments and documentation.

Cc: Jiaxin Wu <jiaxin.wu@intel.com>
Cc: Siyuan Fu <siyuan.fu@intel.com>
Cc: Maciej Rabeda <maciej.rabeda@intel.com>
Reviewed-by: Philippe Mathieu-Daude <philmd@redhat.com>
Signed-off-by: Philippe Mathieu-Daude <philmd@redhat.com>
---
 NetworkPkg/Include/Library/HttpLib.h         |  2 +-
 NetworkPkg/Include/Library/IpIoLib.h         |  4 ++--
 NetworkPkg/Include/Library/NetLib.h          |  2 +-
 NetworkPkg/Include/Library/TcpIoLib.h        |  6 +++---
 NetworkPkg/Include/Library/UdpIoLib.h        |  6 +++---
 NetworkPkg/Library/DxeHttpLib/DxeHttpLib.c   |  4 ++--
 NetworkPkg/Library/DxeIpIoLib/DxeIpIoLib.c   | 16 ++++++++--------
 NetworkPkg/Library/DxeNetLib/DxeNetLib.c     | 16 ++++++++--------
 NetworkPkg/Library/DxeNetLib/NetBuffer.c     |  4 ++--
 NetworkPkg/Library/DxeTcpIoLib/DxeTcpIoLib.c | 10 +++++-----  NetworkPkg/Library/DxeUdpIoLib/DxeUdpIoLib.c | 10 +++++-----
 11 files changed, 40 insertions(+), 40 deletions(-)

diff --git a/NetworkPkg/Include/Library/HttpLib.h b/NetworkPkg/Include/Library/HttpLib.h
index 93100eb350e5..a906126b3d6e 100644
--- a/NetworkPkg/Include/Library/HttpLib.h
+++ b/NetworkPkg/Include/Library/HttpLib.h
@@ -425,7 +425,7 @@ HttpFreeHeaderFields (
                                   the HTTP request message.
   @param[in]   Url                The URL of a remote host.
   @param[out]  RequestMsg         Pointer to the created HTTP request message.
-                                  NULL if any error occured.
+                                  NULL if any error occurred.
   @param[out]  RequestMsgSize     Size of the RequestMsg (in bytes).
 
   @retval EFI_SUCCESS             If HTTP request string was created successfully.
diff --git a/NetworkPkg/Include/Library/IpIoLib.h b/NetworkPkg/Include/Library/IpIoLib.h
index 2d6e090f754e..d95413e87eb1 100644
--- a/NetworkPkg/Include/Library/IpIoLib.h
+++ b/NetworkPkg/Include/Library/IpIoLib.h
@@ -403,7 +403,7 @@ IpIoOpen (
 
   This function is called after IpIoOpen(). The data to be sent is wrapped in
   Pkt. The IP instance wrapped in IpIo is used for sending by default but can be
-  overriden by Sender. Other sending configs, like source address and gateway
+  overridden by Sender. Other sending configs, like source address and 
+ gateway
   address etc., are specified in OverrideData.
 
   @param[in, out]  IpIo                  Pointer to an IP_IO instance used for sending IP
@@ -508,7 +508,7 @@ IpIoConfigIp (
 
   This function pairs with IpIoAddIp(). The IpInfo is previously created by
   IpIoAddIp(). The IP_IO_IP_INFO::RefCnt is decremented and the IP instance
-  will be dstroyed if the RefCnt is zero.
+  will be destroyed if the RefCnt is zero.
 
   @param[in]  IpIo                  The pointer to the IP_IO instance.
   @param[in]  IpInfo                The pointer to the IpInfo to be removed.
diff --git a/NetworkPkg/Include/Library/NetLib.h b/NetworkPkg/Include/Library/NetLib.h
index 786382a1fcff..858d0b6ba07c 100644
--- a/NetworkPkg/Include/Library/NetLib.h
+++ b/NetworkPkg/Include/Library/NetLib.h
@@ -748,7 +748,7 @@ EFI_STATUS
   If it has been removed, then restart the traversal from the head.
   If it hasn't been removed, then continue with the next node directly.
   This function will end the iterate and return the CallBack's last return value if error happens,
-  or retrun EFI_SUCCESS if 2 complete passes are made with no changes in the number of children in the list.
+  or return EFI_SUCCESS if 2 complete passes are made with no changes in the number of children in the list.
 
   @param[in]    List             The head of the list.
   @param[in]    CallBack         Pointer to the callback function to destroy one node in the list.
diff --git a/NetworkPkg/Include/Library/TcpIoLib.h b/NetworkPkg/Include/Library/TcpIoLib.h
index 63872f615c0a..13c163ce9920 100644
--- a/NetworkPkg/Include/Library/TcpIoLib.h
+++ b/NetworkPkg/Include/Library/TcpIoLib.h
@@ -200,7 +200,7 @@ TcpIoReset (
   @param[in]   TcpIo           The TcpIo wrapping the TCP socket.
   @param[in]   Packet          The packet to transmit.
 
-  @retval EFI_SUCCESS            The packet is trasmitted.
+  @retval EFI_SUCCESS            The packet is transmitted.
   @retval EFI_INVALID_PARAMETER  One or more parameters are invalid.
   @retval EFI_UNSUPPORTED        One or more of the control options are not
                                  supported in the implementation.
@@ -221,14 +221,14 @@ TcpIoTransmit (
 
   @param[in, out]  TcpIo       The TcpIo which wraps the socket to be destroyed.
   @param[in]       Packet      The buffer to hold the data copy from the socket rx buffer.
-  @param[in]       AsyncMode   Is this receive asyncronous or not.
+  @param[in]       AsyncMode   Is this receive asynchronous or not.
   @param[in]       Timeout     The time to wait for receiving the amount of data the Packet
                                can hold. Set to NULL for infinite wait.
 
   @retval EFI_SUCCESS            The required amount of data is received from the socket.
   @retval EFI_INVALID_PARAMETER  One or more parameters are invalid.
   @retval EFI_DEVICE_ERROR       An unexpected network or system error occurred.
-  @retval EFI_OUT_OF_RESOURCES   Failed to allocate momery.
+  @retval EFI_OUT_OF_RESOURCES   Failed to allocate memory.
   @retval EFI_TIMEOUT            Failed to receive the required amount of data in the
                                  specified time period.
   @retval Others                 Other errors as indicated.
diff --git a/NetworkPkg/Include/Library/UdpIoLib.h b/NetworkPkg/Include/Library/UdpIoLib.h
index c3cddfafb151..cd4ebeb87a43 100644
--- a/NetworkPkg/Include/Library/UdpIoLib.h
+++ b/NetworkPkg/Include/Library/UdpIoLib.h
@@ -43,7 +43,7 @@ typedef struct {
 
   This prototype is used by both receive and sending when calling
   UdpIoRecvDatagram() or UdpIoSendDatagram(). When receiving, Netbuf is allocated by the
-  UDP access point and released by the user. When sending, the user allocates the the NetBuf,
+  UDP access point and released by the user. When sending, the user 
+ allocates the NetBuf,
   which is then provided to the callback as a reference.
 
   @param[in] Packet       The packet received or sent.
@@ -197,7 +197,7 @@ BOOLEAN
 
   @param[in]  UdpIo                 The UDP_IO to cancel packet.
   @param[in]  IoStatus              The IoStatus to return to the packet owners.
-  @param[in]  ToCancel              The select funtion to test whether to cancel this
+  @param[in]  ToCancel              The select function to test whether to cancel this
                                     packet or not.
   @param[in]  Context               The opaque parameter to the ToCancel.
 
@@ -228,7 +228,7 @@ UdpIoCancelDgrams (
   @param[in]  ImageHandle           The image handle for the driver.
   @param[in]  Configure             The function to configure the created UDP child.
   @param[in]  UdpVersion            The UDP protocol version, UDP4 or UDP6.
-  @param[in]  Context               The opaque parameter for the Configure funtion.
+  @param[in]  Context               The opaque parameter for the Configure function.
 
   @return The newly-created UDP_IO, or NULL if failed.
 
diff --git a/NetworkPkg/Library/DxeHttpLib/DxeHttpLib.c b/NetworkPkg/Library/DxeHttpLib/DxeHttpLib.c
index 8b74554cd961..180d9321025a 100644
--- a/NetworkPkg/Library/DxeHttpLib/DxeHttpLib.c
+++ b/NetworkPkg/Library/DxeHttpLib/DxeHttpLib.c
@@ -1677,7 +1677,7 @@ HttpGetFieldNameAndValue (
 /**
   Free existing HeaderFields.
 
-  @param[in]  HeaderFields       Pointer to array of key/value header pairs waitting for free.
+  @param[in]  HeaderFields       Pointer to array of key/value header pairs waiting for free.
   @param[in]  FieldCount         The number of header pairs in HeaderFields.
 
 **/
@@ -1717,7 +1717,7 @@ HttpFreeHeaderFields (
                                   the HTTP request message.
   @param[in]   Url                The URL of a remote host.
   @param[out]  RequestMsg         Pointer to the created HTTP request message.
-                                  NULL if any error occured.
+                                  NULL if any error occurred.
   @param[out]  RequestMsgSize     Size of the RequestMsg (in bytes).
 
   @retval EFI_SUCCESS             If HTTP request string was created successfully.
diff --git a/NetworkPkg/Library/DxeNetLib/DxeNetLib.c b/NetworkPkg/Library/DxeNetLib/DxeNetLib.c
index 4f8a1226dae7..2a555a7b90fa 100644
--- a/NetworkPkg/Library/DxeNetLib/DxeNetLib.c
+++ b/NetworkPkg/Library/DxeNetLib/DxeNetLib.c
@@ -36,7 +36,7 @@ SPDX-License-Identifier: BSD-2-Clause-Patent
 #define DEFAULT_ZERO_START     ((UINTN) ~0)
 
 //
-// All the supported IP4 maskes in host byte order.
+// All the supported IP4 masks in host byte order.
 //
 GLOBAL_REMOVE_IF_UNREFERENCED IP4_ADDR  gIp4AllMasks[IP4_MASK_NUM] = {
   0x00000000,
@@ -130,7 +130,7 @@ GLOBAL_REMOVE_IF_UNREFERENCED VLAN_DEVICE_PATH mNetVlanDevicePathTemplate = {
   to send the syslog packets. The caller isn't required to close
   the SNP after use because the SNP is opened by HandleProtocol.
 
-  @return The point to SNP if one is properly openned. Otherwise NULL
+  @return The point to SNP if one is properly opened. Otherwise NULL
 
 **/
 EFI_SIMPLE_NETWORK_PROTOCOL *
@@ -304,7 +304,7 @@ ON_EXIT:
   @param[in]  File      The file that contains the current log
   @param[in]  Line      The line of code in the File that contains the current log
   @param[in]  Message   The log message
-  @param[in]  BufLen    The lenght of the Buf
+  @param[in]  BufLen    The length of the Buf
   @param[out] Buf       The buffer to put the packet data
 
   @return The length of the syslog packet built, 0 represents no packet is built.
@@ -480,7 +480,7 @@ NetDebugASPrint (
   Because it isn't open the SNP BY_DRIVER, apply caution when using it.
 
   @param Level    The severity level of the message.
-  @param Module   The Moudle that generates the log.
+  @param Module   The Module that generates the log.
   @param File     The file that contains the log.
   @param Line     The exact line that contains the log.
   @param Message  The user message to log.
@@ -518,7 +518,7 @@ NetDebugOutput (
   }
 
   //
-  // Allocate a maxium of 1024 bytes, the caller should ensure
+  // Allocate a maximum of 1024 bytes, the caller should ensure
   // that the message plus the ethernet/ip/udp header is shorter
   // than this
   //
@@ -1129,7 +1129,7 @@ NetListInsertBefore (
   If it has been removed, then restart the traversal from the head.
   If it hasn't been removed, then continue with the next node directly.
   This function will end the iterate and return the CallBack's last return value if error happens,
-  or retrun EFI_SUCCESS if 2 complete passes are made with no changes in the number of children in the list.
+  or return EFI_SUCCESS if 2 complete passes are made with no changes in the number of children in the list.
 
   @param[in]    List             The head of the list.
   @param[in]    CallBack         Pointer to the callback function to destroy one node in the list.
@@ -1353,7 +1353,7 @@ NetMapGetCount (
   Return one allocated item.
 
   If the Recycled doubly linked list of the netmap is empty, it will try to allocate
-  a batch of items if there are enough resources and add corresponding nodes to the begining
+  a batch of items if there are enough resources and add corresponding 
+ nodes to the beginning
   of the Recycled doubly linked list of the netmap. Otherwise, it will directly remove
   the fist node entry of the Recycled doubly linked list and return the corresponding item.
 
@@ -3299,7 +3299,7 @@ NetLibGetSystemGuid (
     String = (CHAR8 *) (Smbios.Raw + Smbios.Hdr->Length);
 
     //
-    // Step 2: Skip over unformated string section.
+    // Step 2: Skip over unformatted string section.
     //
     do {
       //
diff --git a/NetworkPkg/Library/DxeNetLib/NetBuffer.c b/NetworkPkg/Library/DxeNetLib/NetBuffer.c
index 2408e9a10456..a232802c9a21 100644
--- a/NetworkPkg/Library/DxeNetLib/NetBuffer.c
+++ b/NetworkPkg/Library/DxeNetLib/NetBuffer.c
@@ -602,7 +602,7 @@ NetbufGetFragment (
 
   if (HeadSpace != 0) {
     //
-    // Allocate an extra block to accomdate the head space.
+    // Allocate an extra block to accommodate the head space.
     //
     BlockOpNum++;
 
@@ -791,7 +791,7 @@ NetbufFromExt (
 
         if (Len == 0) {
           //
-          // Increament the index number to point to the next
+          // Increment the index number to point to the next
           // non-empty fragment.
           //
           Index++;
diff --git a/NetworkPkg/Library/DxeTcpIoLib/DxeTcpIoLib.c b/NetworkPkg/Library/DxeTcpIoLib/DxeTcpIoLib.c
index 341295d0b7af..6f87a0eada98 100644
--- a/NetworkPkg/Library/DxeTcpIoLib/DxeTcpIoLib.c
+++ b/NetworkPkg/Library/DxeTcpIoLib/DxeTcpIoLib.c
@@ -304,7 +304,7 @@ TcpIoCreateSocket (
   }
 
   //
-  // Create events for variuos asynchronous operations.
+  // Create events for various asynchronous operations.
   //
   Status = gBS->CreateEvent (
                   EVT_NOTIFY_SIGNAL,
@@ -745,7 +745,7 @@ TcpIoReset (
   @param[in]   TcpIo           The TcpIo wrapping the TCP socket.
   @param[in]   Packet          The packet to transmit.
 
-  @retval EFI_SUCCESS            The packet is trasmitted.
+  @retval EFI_SUCCESS            The packet is transmitted.
   @retval EFI_INVALID_PARAMETER  One or more parameters are invalid.
   @retval EFI_UNSUPPORTED        One or more of the control options are not
                                  supported in the implementation.
@@ -807,7 +807,7 @@ TcpIoTransmit (
   Status = EFI_DEVICE_ERROR;
 
   //
-  // Trasnmit the packet.
+  // Transmit the packet.
   //
   if (TcpIo->TcpVersion == TCP_VERSION_4) {
     TcpIo->TxToken.Tcp4Token.Packet.TxData = (EFI_TCP4_TRANSMIT_DATA *) Data; @@ -862,14 +862,14 @@ ON_EXIT:
 
   @param[in, out]  TcpIo       The TcpIo which wraps the socket to be destroyed.
   @param[in]       Packet      The buffer to hold the data copy from the socket rx buffer.
-  @param[in]       AsyncMode   Is this receive asyncronous or not.
+  @param[in]       AsyncMode   Is this receive asynchronous or not.
   @param[in]       Timeout     The time to wait for receiving the amount of data the Packet
                                can hold. Set to NULL for infinite wait.
 
   @retval EFI_SUCCESS            The required amount of data is received from the socket.
   @retval EFI_INVALID_PARAMETER  One or more parameters are invalid.
   @retval EFI_DEVICE_ERROR       An unexpected network or system error occurred.
-  @retval EFI_OUT_OF_RESOURCES   Failed to allocate momery.
+  @retval EFI_OUT_OF_RESOURCES   Failed to allocate memory.
   @retval EFI_TIMEOUT            Failed to receive the required amount of data in the
                                  specified time period.
   @retval Others                 Other errors as indicated.
diff --git a/NetworkPkg/Library/DxeUdpIoLib/DxeUdpIoLib.c b/NetworkPkg/Library/DxeUdpIoLib/DxeUdpIoLib.c
index 155cb3104972..0034a5694f92 100644
--- a/NetworkPkg/Library/DxeUdpIoLib/DxeUdpIoLib.c
+++ b/NetworkPkg/Library/DxeUdpIoLib/DxeUdpIoLib.c
@@ -147,7 +147,7 @@ UdpIoRecycleDgram (
 /**
   The event handle for UDP receive request.
 
-  It will build a NET_BUF from the recieved UDP data, then deliver it
+  It will build a NET_BUF from the received UDP data, then deliver it
   to the receiver.
 
   @param[in]  Context               The UDP RX token.
@@ -335,7 +335,7 @@ UdpIoOnDgramRcvd (
   @param[in]  UdpIo                 The UdpIo to receive packets from.
   @param[in]  CallBack              The function to call when receive finished.
   @param[in]  Context               The opaque parameter to the CallBack.
-  @param[in]  HeadLen               The head length to reserver for the packet.
+  @param[in]  HeadLen               The head length to reserve for the packet.
 
   @return The Wrapped request or NULL if failed to allocate resources or some errors happened.
 
@@ -410,7 +410,7 @@ UdpIoCreateRxToken (
   @param[in]  UdpIo                 The UdpIo to send packet to.
   @param[in]  Packet                The user's packet.
   @param[in]  EndPoint              The local and remote access point.
-  @param[in]  Gateway               The overrided next hop.
+  @param[in]  Gateway               The overridden next hop.
   @param[in]  CallBack              The function to call when transmission completed.
   @param[in]  Context               The opaque parameter to the call back.
 
@@ -590,7 +590,7 @@ UdpIoCreateTxToken (
   @param[in]  ImageHandle           The image handle for the driver.
   @param[in]  Configure             The function to configure the created UDP child.
   @param[in]  UdpVersion            The UDP protocol version, UDP4 or UDP6.
-  @param[in]  Context               The opaque parameter for the Configure funtion.
+  @param[in]  Context               The opaque parameter for the Configure function.
 
   @return Newly-created UDP_IO or NULL if failed.
 
@@ -755,7 +755,7 @@ FREE_MEM:
 
   @param[in]  UdpIo                 The UDP_IO to cancel packet.
   @param[in]  IoStatus              The IoStatus to return to the packet owners.
-  @param[in]  ToCancel              The select funtion to test whether to cancel this
+  @param[in]  ToCancel              The select function to test whether to cancel this
                                     packet or not.
   @param[in]  Context               The opaque parameter to the ToCancel.
 
diff --git a/NetworkPkg/Library/DxeIpIoLib/DxeIpIoLib.c b/NetworkPkg/Library/DxeIpIoLib/DxeIpIoLib.c
index d45f0070b3fc..0a816da00140 100644
--- a/NetworkPkg/Library/DxeIpIoLib/DxeIpIoLib.c
+++ b/NetworkPkg/Library/DxeIpIoLib/DxeIpIoLib.c
@@ -123,7 +123,7 @@ IpIoTransmitHandler (
 
   @retval       EFI_SUCCESS        The IP child is created and the IP protocol
                                    interface is retrieved.
-  @retval       EFI_UNSUPPORTED    Upsupported IpVersion.
+  @retval       EFI_UNSUPPORTED    Unsupported IpVersion.
   @retval       Others             The required operation failed.
 
 **/
@@ -191,7 +191,7 @@ IpIoCreateIpChildOpenProtocol (
 
 
 /**
-  This function close the previously openned IP protocol and destroy the IP child.
+  This function close the previously opened IP protocol and destroy the IP child.
 
   @param[in]  ControllerHandle    The controller handle.
   @param[in]  ImageHandle         The image handle.
@@ -201,7 +201,7 @@ IpIoCreateIpChildOpenProtocol (
 
   @retval     EFI_SUCCESS         The IP protocol is closed and the relevant IP child
                                   is destroyed.
-  @retval     EFI_UNSUPPORTED     Upsupported IpVersion.
+  @retval     EFI_UNSUPPORTED     Unsupported IpVersion.
   @retval     Others              The required operation failed.
 
 **/
@@ -228,7 +228,7 @@ IpIoCloseProtocolDestroyIpChild (
   }
 
   //
   // Close the previously openned IP protocol.
   //
   Status = gBS->CloseProtocol (
                   ChildHandle,
@@ -626,7 +626,7 @@ IpIoExtFree (
   @param[in]       Context              Pointer to the context.
   @param[in]       NotifyData           Pointer to the notify data.
   @param[in]       Dest                 Pointer to the destination IP address.
-  @param[in]       Override             Pointer to the overriden IP_IO data.
+  @param[in]       Override             Pointer to the overridden IP_IO data.
 
   @return Pointer to the data structure created to wrap the packet. If any error occurs,
           then return NULL.
@@ -1497,7 +1497,7 @@ IpIoStop (
   IpIo->IsConfigured = FALSE;
 
   //
-  // Detroy the Ip List used by IpIo
+  // Destroy the Ip List used by IpIo
   //
 
   while (!IsListEmpty (&(IpIo->IpList))) { @@ -1577,7 +1577,7 @@ IpIoDestroy (
 
   This function is called after IpIoOpen(). The data to be sent is wrapped in
   Pkt. The IP instance wrapped in IpIo is used for sending by default but can be
-  overriden by Sender. Other sending configs, like source address and gateway
+  overridden by Sender. Other sending configs, like source address and 
+ gateway
   address etc., are specified in OverrideData.
 
   @param[in, out]  IpIo                  Pointer to an IP_IO instance used for sending IP
@@ -1991,7 +1991,7 @@ IpIoConfigIp (
 
   This function pairs with IpIoAddIp(). The IpInfo is previously created by
   IpIoAddIp(). The IP_IO_IP_INFO::RefCnt is decremented and the IP instance
-  will be dstroyed if the RefCnt is zero.
+  will be destroyed if the RefCnt is zero.
 
   @param[in]  IpIo                  Pointer to the IP_IO instance.
   @param[in]  IpInfo                Pointer to the IpInfo to be removed.
@@ -228,7 +228,7 @@ IpIoCloseProtocolDestroyIpChild (
 
   //
-  // Close the previously openned IP protocol.
+  // Close the previously opened IP protocol.
   //
   Status = gBS->CloseProtocol (
--
2.21.0

--------------------------------------------------------------------

Intel Technology Poland sp. z o.o.
ul. Slowackiego 173 | 80-298 Gdansk | Sad Rejonowy Gdansk Polnoc | VII Wydzial Gospodarczy Krajowego Rejestru Sadowego - KRS 101882 | NIP 957-07-52-316 | Kapital zakladowy 200.000 PLN.

Ta wiadomosc wraz z zalacznikami jest przeznaczona dla okreslonego adresata i moze zawierac informacje poufne. W razie przypadkowego otrzymania tej wiadomosci, prosimy o powiadomienie nadawcy oraz trwale jej usuniecie; jakiekolwiek
przegladanie lub rozpowszechnianie jest zabronione.
This e-mail and any attachments may contain confidential material for the sole use of the intended recipient(s). If you are not the intended recipient, please contact the sender and delete all copies; any review or distribution by
others is strictly prohibited.

  parent reply	other threads:[~2019-12-06 16:04 UTC|newest]

Thread overview: 122+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2019-12-03 16:14 [PATCH 00/79] Fix a bunch of typos (part 1) Philippe Mathieu-Daudé
2019-12-03 16:14 ` [PATCH 01/79] CryptoPkg/OpensslLib: Fix few typos Philippe Mathieu-Daudé
2019-12-03 16:14 ` [PATCH 02/79] EmbeddedPkg/FdtLib: Fix a typo Philippe Mathieu-Daudé
2019-12-03 16:58   ` Leif Lindholm
2019-12-03 16:14 ` [PATCH 03/79] EmbeddedPkg/VirtualKeyboard: Fix a typo in EFI_INVALID_PARAMETER Philippe Mathieu-Daudé
2019-12-03 16:14 ` [PATCH 04/79] EmbeddedPkg/VirtualKeyboard: Fix few typos Philippe Mathieu-Daudé
2019-12-03 16:14 ` [PATCH 05/79] EmulatorPkg/Sec: Fix various typos Philippe Mathieu-Daudé
2019-12-03 16:14 ` [PATCH 06/79] EmulatorPkg/Unix: " Philippe Mathieu-Daudé
2019-12-20  6:38   ` Ni, Ray
2019-12-03 16:14 ` [PATCH 07/79] EmulatorPkg/Win: " Philippe Mathieu-Daudé
2019-12-03 16:14 ` [PATCH 08/79] FatPkg/EnhancedFatDxe: " Philippe Mathieu-Daudé
2019-12-03 16:14 ` [PATCH 09/79] FatPkg/FatPei: Fix few typos Philippe Mathieu-Daudé
2019-12-20  6:37   ` Ni, Ray
2019-12-03 16:14 ` [PATCH 10/79] IntelFsp2WrapperPkg: Fix various typos Philippe Mathieu-Daudé
2019-12-04  1:14   ` [edk2-devel] " Nate DeSimone
2019-12-04  1:22   ` Chiu, Chasel
2019-12-04  1:40     ` [edk2-devel] " Michael D Kinney
2019-12-04  2:30   ` Zeng, Star
2019-12-11  1:53   ` Chiu, Chasel
2019-12-03 16:14 ` [PATCH 11/79] MdeModulePkg/Application: Improve French translation Philippe Mathieu-Daudé
2019-12-03 16:14 ` [PATCH 12/79] MdeModulePkg/Application: Fix various typos Philippe Mathieu-Daudé
2019-12-03 16:14 ` [PATCH 13/79] MdeModulePkg/Bus/Ata: " Philippe Mathieu-Daudé
2019-12-03 16:14 ` [PATCH 14/79] MdeModulePkg/Bus/I2c: Fix few typos Philippe Mathieu-Daudé
2019-12-03 16:14 ` [PATCH 15/79] MdeModulePkg/Bus/Isa: Fix various typos Philippe Mathieu-Daudé
2019-12-03 16:14 ` [PATCH 16/79] MdeModulePkg/Bus/Scsi: " Philippe Mathieu-Daudé
2019-12-03 16:15 ` [PATCH 17/79] MdeModulePkg/Bus/Sd: " Philippe Mathieu-Daudé
2019-12-03 16:15 ` [PATCH 18/79] MdeModulePkg/Core/Pei: " Philippe Mathieu-Daudé
2019-12-03 16:15 ` [PATCH 19/79] MdeModulePkg/Core/PiSmmCore: " Philippe Mathieu-Daudé
2019-12-03 16:15 ` [PATCH 20/79] MdeModulePkg/UsbBusDxe: Fix a typo Philippe Mathieu-Daudé
2019-12-03 16:15 ` [PATCH 21/79] MdeModulePkg/UsbMass: Fix various typos Philippe Mathieu-Daudé
2019-12-03 16:15 ` [PATCH 22/79] MdeModulePkg/UsbMouse: Fix few typos Philippe Mathieu-Daudé
2019-12-03 16:15 ` [PATCH 23/79] MdeModulePkg/UsbBus: Fix various typos Philippe Mathieu-Daudé
2019-12-03 16:15 ` [PATCH 24/79] MdeModulePkg/Usb: " Philippe Mathieu-Daudé
2019-12-03 16:15 ` [PATCH 25/79] MdePkg/IndustryStandard: " Philippe Mathieu-Daudé
2019-12-04  1:35   ` Michael D Kinney
2019-12-03 16:15 ` [PATCH 26/79] MdePkg/Library/Dxe: " Philippe Mathieu-Daudé
2019-12-04  1:24   ` [edk2-devel] " Michael D Kinney
2019-12-03 16:15 ` [PATCH 27/79] MdePkg/Library/Pci: " Philippe Mathieu-Daudé
2019-12-04  1:25   ` [edk2-devel] " Michael D Kinney
2019-12-03 16:15 ` [PATCH 28/79] MdePkg/Library/Smm: " Philippe Mathieu-Daudé
2019-12-04  1:28   ` Michael D Kinney
2019-12-03 16:15 ` [PATCH 29/79] MdePkg/Ppi: " Philippe Mathieu-Daudé
2019-12-04  1:29   ` [edk2-devel] " Michael D Kinney
2019-12-03 16:15 ` [PATCH 30/79] MdePkg/Register: " Philippe Mathieu-Daudé
2019-12-04  1:30   ` [edk2-devel] " Michael D Kinney
2019-12-03 16:15 ` [PATCH 31/79] NetworkPkg: Fix a typo Philippe Mathieu-Daudé
2019-12-03 17:18   ` Leif Lindholm
2019-12-03 17:20     ` Philippe Mathieu-Daudé
2019-12-04 14:02       ` [edk2-devel] " Maciej Rabeda
2019-12-03 16:15 ` [PATCH 32/79] NetworkPkg/ArpDxe: Fix various typos Philippe Mathieu-Daudé
2019-12-04 13:20   ` [edk2-devel] " Maciej Rabeda
2019-12-03 16:15 ` [PATCH 33/79] NetworkPkg/Dhcp4Dxe: " Philippe Mathieu-Daudé
2019-12-04 13:25   ` [edk2-devel] " Maciej Rabeda
2019-12-03 16:15 ` [PATCH 34/79] NetworkPkg/Dhcp6Dxe: " Philippe Mathieu-Daudé
2019-12-04 13:28   ` [edk2-devel] " Maciej Rabeda
2019-12-03 16:15 ` [PATCH 35/79] NetworkPkg/DnsDxe: Fix a typo Philippe Mathieu-Daudé
2019-12-04 13:35   ` [edk2-devel] " Maciej Rabeda
2019-12-03 16:15 ` [PATCH 36/79] NetworkPkg/DnsDxe: Fix various typos Philippe Mathieu-Daudé
2019-12-04 13:36   ` [edk2-devel] " Maciej Rabeda
2019-12-03 16:15 ` [PATCH 37/79] NetworkPkg/DpcDxe: Fix few typos Philippe Mathieu-Daudé
2019-12-04 13:37   ` [edk2-devel] " Maciej Rabeda
2019-12-03 16:15 ` [PATCH 38/79] NetworkPkg/HttpBootDxe: Fix a typo in variable name Philippe Mathieu-Daudé
2019-12-04 13:52   ` [edk2-devel] " Maciej Rabeda
2019-12-03 16:15 ` [PATCH 39/79] NetworkPkg/HttpBootDxe: Fix various typos Philippe Mathieu-Daudé
2019-12-04 13:53   ` [edk2-devel] " Maciej Rabeda
2019-12-03 16:26 ` [PATCH 00/79] Fix a bunch of typos (part 1) Cœur
     [not found] ` <20191203161602.15969-61-philmd@redhat.com>
2019-12-03 16:45   ` [PATCH 60/79] OvmfPkg/Xen: Fix a typo Anthony PERARD
2019-12-03 21:05   ` Laszlo Ersek
     [not found] ` <20191203161602.15969-62-philmd@redhat.com>
2019-12-03 16:56   ` [PATCH 61/79] OvmfPkg/Xen: Fix various typos Anthony PERARD
2019-12-03 21:06     ` Laszlo Ersek
2019-12-04  3:39     ` Cœur
2019-12-04 16:07       ` [edk2-devel] " Michael D Kinney
2019-12-09 13:06         ` Philippe Mathieu-Daudé
2019-12-09 17:53           ` Michael D Kinney
     [not found] ` <20191203161602.15969-76-philmd@redhat.com>
2019-12-03 19:44   ` [PATCH 75/79] StandaloneMmPkg: Fix a typo Yao, Jiewen
     [not found] ` <20191203161602.15969-77-philmd@redhat.com>
2019-12-03 19:45   ` [PATCH 76/79] StandaloneMmPkg: Fix few typos Yao, Jiewen
     [not found] ` <20191203161602.15969-57-philmd@redhat.com>
2019-12-03 20:48   ` [PATCH 56/79] OvmfPkg/Acpi: " Laszlo Ersek
     [not found] ` <20191203161602.15969-58-philmd@redhat.com>
2019-12-03 20:50   ` [PATCH 57/79] OvmfPkg/Csm: Fix various typos Laszlo Ersek
2019-12-03 23:31     ` David Woodhouse
2019-12-04 14:07       ` [edk2-devel] " Philippe Mathieu-Daudé
     [not found] ` <20191203161602.15969-59-philmd@redhat.com>
2019-12-03 21:00   ` [PATCH 58/79] OvmfPkg/Qemu: " Laszlo Ersek
2019-12-09 12:55     ` Philippe Mathieu-Daudé
2019-12-09 13:00       ` Philippe Mathieu-Daudé
2019-12-09 16:12         ` Laszlo Ersek
2019-12-09 15:44       ` Laszlo Ersek
     [not found] ` <20191203161602.15969-60-philmd@redhat.com>
2019-12-03 21:00   ` [PATCH 59/79] OvmfPkg/Virtio: Fix few typos Laszlo Ersek
     [not found] ` <20191203161602.15969-78-philmd@redhat.com>
2019-12-03 21:03   ` [PATCH 77/79] UefiCpuPkg/CpuDxe: " Laszlo Ersek
2019-12-06  7:24   ` Dong, Eric
     [not found] ` <20191203161602.15969-79-philmd@redhat.com>
2019-12-03 21:04   ` [PATCH 78/79] UefiCpuPkg/PiSmm: Fix various typos Laszlo Ersek
2019-12-06  7:24   ` Dong, Eric
     [not found] ` <20191203161602.15969-80-philmd@redhat.com>
2019-12-03 21:05   ` [PATCH 79/79] UefiCpuPkg/Smm: " Laszlo Ersek
2019-12-06  7:24   ` Dong, Eric
     [not found] ` <20191203161602.15969-73-philmd@redhat.com>
2019-12-04  1:03   ` [PATCH 72/79] SourceLevelDebugPkg/DebugAgent: " Wu, Hao A
     [not found] ` <20191203161602.15969-74-philmd@redhat.com>
2019-12-04  1:03   ` [PATCH 73/79] SourceLevelDebugPkg/DebugCommunicationLib: " Wu, Hao A
     [not found] ` <20191203161602.15969-75-philmd@redhat.com>
2019-12-04  1:03   ` [PATCH 74/79] SourceLevelDebugPkg: Fix few typos Wu, Hao A
2019-12-04  1:16 ` [edk2-devel] [PATCH 00/79] Fix a bunch of typos (part 1) Nate DeSimone
2019-12-04  1:27   ` Liming Gao
2019-12-04  9:09     ` Laszlo Ersek
2019-12-04 14:57       ` Maciej Rabeda
2019-12-04 16:29   ` Philippe Mathieu-Daudé
2019-12-04 16:44     ` Leif Lindholm
2019-12-04 22:15       ` Laszlo Ersek
2019-12-04 22:18         ` Philippe Mathieu-Daudé
     [not found] ` <20191203161602.15969-56-philmd@redhat.com>
2019-12-06 16:01   ` [PATCH 55/79] NetworkPkg/VlanConfigDxe: Fix few typos Rabeda, Maciej
     [not found] ` <20191203161602.15969-55-philmd@redhat.com>
2019-12-06 16:01   ` [PATCH 54/79] NetworkPkg/UefiPxeBcDxe: Fix various typos Rabeda, Maciej
     [not found] ` <20191203161602.15969-52-philmd@redhat.com>
2019-12-06 16:01   ` [PATCH 51/79] NetworkPkg/Tls: Fix few typos Rabeda, Maciej
     [not found] ` <20191203161602.15969-51-philmd@redhat.com>
2019-12-06 16:02   ` [PATCH 50/79] NetworkPkg/TcpDxe/Tcp: Fix various typos Rabeda, Maciej
     [not found] ` <20191203161602.15969-47-philmd@redhat.com>
2019-12-06 16:02   ` [PATCH 46/79] NetworkPkg/Mtftp4Dxe: " Rabeda, Maciej
     [not found] ` <20191203161602.15969-53-philmd@redhat.com>
2019-12-06 16:02   ` [PATCH 52/79] NetworkPkg/Udp4Dxe: " Rabeda, Maciej
     [not found] ` <20191203161602.15969-54-philmd@redhat.com>
2019-12-06 16:03   ` [PATCH 53/79] NetworkPkg/Udp6Dxe: " Rabeda, Maciej
     [not found] ` <20191203161602.15969-43-philmd@redhat.com>
2019-12-06 16:03   ` [PATCH 42/79] NetworkPkg/Ip6Dxe: " Rabeda, Maciej
     [not found] ` <20191203161602.15969-45-philmd@redhat.com>
2019-12-06 16:04   ` Rabeda, Maciej [this message]
     [not found] ` <20191203161602.15969-42-philmd@redhat.com>
2019-12-06 16:04   ` [PATCH 41/79] NetworkPkg/Ip4Dxe: " Rabeda, Maciej
     [not found] ` <20191203161602.15969-50-philmd@redhat.com>
2019-12-06 16:04   ` [PATCH 49/79] NetworkPkg/TcpDxe/Sock: Fix few typos Rabeda, Maciej
     [not found] ` <20191203161602.15969-48-philmd@redhat.com>
2019-12-06 16:05   ` [PATCH 47/79] NetworkPkg/Mtftp6Dxe: Fix various typos Rabeda, Maciej
     [not found] ` <20191203161602.15969-46-philmd@redhat.com>
2019-12-06 16:05   ` [PATCH 45/79] NetworkPkg/MnpDxe: " Rabeda, Maciej
     [not found] ` <20191203161602.15969-41-philmd@redhat.com>
2019-12-06 16:05   ` [PATCH 40/79] NetworkPkg/HttpDxe: " Rabeda, Maciej
     [not found] ` <20191203161602.15969-49-philmd@redhat.com>
2019-12-06 16:09   ` [PATCH 48/79] NetworkPkg/SnpDxe: Fix few typos Rabeda, Maciej
2019-12-06 16:38     ` Philippe Mathieu-Daudé
2019-12-10  7:21 ` [PATCH 00/79] Fix a bunch of typos (part 1) Cœur
     [not found] ` <20191203161602.15969-70-philmd@redhat.com>
2019-12-13  2:33   ` [PATCH 69/79] ShellPkg/DynamicCommand: Fix various typos Gao, Zhichao
     [not found] ` <20191203161602.15969-69-philmd@redhat.com>
2019-12-13  2:33   ` [PATCH 68/79] ShellPkg/Application: " Gao, Zhichao

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-list from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=SN6PR11MB35357B0AFA6595E9A8E79272F95F0@SN6PR11MB3535.namprd11.prod.outlook.com \
    --to=devel@edk2.groups.io \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox